@@ -4,8 +4,6 @@
 import tempfile
 import cv2
 import shutil
-import sys
-from io import BytesIO
 
 from pathlib import Path
 from ladybug.dt import DateTime
@@ -297,7 +295,7 @@ def _serialized_images_and_timestamps(grid_folder: Path,
     We are iterating through all the time period folders and pulling images out of them.
     We are renaming these images based on the image count before writing to a folder
     named 'serialized'. This helps us down the line when we need to use the images in
-    order. While translating, we're also generating the time stamp annotation to put
+    order. While translating, we're also generating the time step annotation to put
     on the images later.
 
     Args:
@@ -314,11 +312,22 @@ def _serialized_images_and_timestamps(grid_folder: Path,
     serialized_images_folder = temp_folder.joinpath('serialized')
     serialized_images_folder.mkdir()
 
+    dec, mar, jun = [], [], []
+
+    for image_path in list(grid_folder.iterdir()):
+        if 1416 <= float(image_path.stem.split('_')[0]) <= 2156:
+            mar.append(image_path)
+        elif 3624 <= float(image_path.stem.split('_')[0]) <= 4343:
+            jun.append(image_path)
+        else:
+            dec.append(image_path)
+
+    grouped_images: List[List[Path]] = [dec, mar, jun]
+
     image_count = 0
-    for time_step_folder in list(grid_folder.iterdir()):
-        for image_path in list(time_step_folder.iterdir()):
-            _rename_image(
-                image_path, serialized_images_folder, str(image_count))
+    for month in grouped_images:
+        for image_path in month:
+            _rename_image(image_path, serialized_images_folder, str(image_count))
             time_stamps.append(_hoy_to_text(image_path))
             image_count += 1
 
@@ -377,9 +386,8 @@ def _transparent_translucent(temp_folder: Path, images_folder: Path,
 
 def write_gif(time_step_images_path: str, target_path: str = '.',
               gradient_transparency: bool = False,
-              gif_name: str = 'output',
-              gif_duration: int = 1000,
-              gif_loop_count: int = 0,
+              duration: int = 1000,
+              loop_count: int = 0,
               linger_last_frame: int = 3) -> str:
     """Export a GIF from a time step images.
 
@@ -395,9 +403,8 @@ def write_gif(time_step_images_path: str, target_path: str = '.',
             the image in the back more transparent compared to the image in the front.
             Defaults to False which will use a flat transparency. which means the
             all images will have same amount of transparency.
-        gif_name: The name of the gif. Defaults to 'output'.
-        gif_duration: The duration of the gif in milliseconds. Defaults to 1000.
-        gif_loop_count: The number of times to loop the gif. Defaults to 0 which will
+        duration: The duration of the gif in milliseconds. Defaults to 1000.
+        loop_count: The number of times to loop the gif. Defaults to 0 which will
             loop infinitely.
         linger_last_frame: An integer that will make the last frame linger for longer
             than the duration. If set to 0, the last frame will not linger. Setting it
@@ -418,11 +425,6 @@ def write_gif(time_step_images_path: str, target_path: str = '.',
 
     for grid_folder in time_step_images_folder.iterdir():
 
-        grid_gif_folder = target_folder.joinpath(f'{grid_folder.stem}_gif')
-        if grid_gif_folder.is_dir():
-            shutil.rmtree(grid_gif_folder)
-        grid_gif_folder.mkdir()
-
         temp_folder = Path(tempfile.mkdtemp())
 
         serialized_images_folder, time_stamp_strings = _serialized_images_and_timestamps(
@@ -446,8 +448,8 @@ def write_gif(time_step_images_path: str, target_path: str = '.',
                                              len(time_stamp_strings))
 
         _gif(temp_folder, annotated_folder,
-             grid_gif_folder, len(time_stamp_strings), gif_name,
-             gif_duration, gif_loop_count, linger_last_frame)
+             target_folder, len(time_stamp_strings), grid_folder.stem,
+             duration, loop_count, linger_last_frame)
 
         try:
             shutil.rmtree(temp_folder)
@@ -477,7 +479,8 @@ def write_transparent_images(time_step_images_path: str, target_path: str = '.',
     """
 
     time_step_images_folder = Path(time_step_images_path)
-    assert time_step_images_folder.is_dir(), 'The images folder must be a directory.'
+    assert time_step_images_folder.is_dir(), 'The images folder must be a directory.' \
+        f' Make sure the path is correct. Given path is {time_step_images_path}'
     assert len(list(time_step_images_folder.glob('*'))) > 0, 'The images folder must'
     ' not be empty.'
 
@@ -486,7 +489,7 @@ def write_transparent_images(time_step_images_path: str, target_path: str = '.',
 
     for grid_folder in time_step_images_folder.iterdir():
 
-        grid_images_folder = target_folder.joinpath(f'{grid_folder.stem}_images')
+        grid_images_folder = target_folder.joinpath(f'{grid_folder.stem}_trans_images')
         if grid_images_folder.is_dir():
             shutil.rmtree(grid_images_folder)
         grid_images_folder.mkdir()
@@ -494,15 +497,14 @@ def write_transparent_images(time_step_images_path: str, target_path: str = '.',
         temp_folder = Path(tempfile.mkdtemp())
 
         image_count = 0
-        for time_step_folder in grid_folder.iterdir():
-            for image_path in time_step_folder.iterdir():
-                image = Image.open(image_path.as_posix())
-                image = _translucent(image, transparency)
-                image = _transparent_background(image)
-                text = _hoy_to_text(image_path)
-                image = _annotate_image(image, text, 25)
-                image.save(f'{grid_images_folder}/{image_count}.png', 'PNG')
-                image_count += 1
+        for image_path in grid_folder.iterdir():
+            image = Image.open(image_path.as_posix())
+            image = _translucent(image, transparency)
+            image = _transparent_background(image)
+            text = _hoy_to_text(image_path)
+            image = _annotate_image(image, text, 25)
+            image.save(f'{grid_images_folder}/{image_count}.png', 'PNG')
+            image_count += 1
         try:
             shutil.rmtree(temp_folder)
         except Exception:
