@@ -42,6 +42,7 @@ class Scene:
         self.background_color = background_color
         self.actors = actors or []
         self.cameras = cameras or []
+        self.legend_parameters = {}
         self.text_actor = text_actor
         self._assistants = []
 
@@ -122,10 +123,14 @@ class Scene:
     @property
     def legend_parameters(self) -> Dict[str, LegendParameter]:
         """Legends in the scene that can be added to the images."""
-        legends_dict = {}
         for actor in self._actors:
-            legends_dict[actor.legend_parameter.name] = actor.legend_parameter
-        return legends_dict
+            self._legend_parameters[actor.legend_parameter.name] = actor.legend_parameter
+        return self._legend_parameters
+
+    @legend_parameters.setter
+    def legend_parameters(self, val: Dict[str, LegendParameter]) -> None:
+        """Set legend parameters for the scene."""
+        self._legend_parameters = val
 
     def legend_parameter(self, name: str) -> LegendParameter:
         """Get a legend parameter object by name.
@@ -209,14 +214,18 @@ class Scene:
     def export_images(
             self, folder: str, image_type: ImageTypes = ImageTypes.png, *,
             image_scale: int = 1, image_width: int = 0, image_height: int = 0,
-            color_range: vtk.vtkLookupTable = None, rgba: bool = False,
-            show: bool = False) -> List[str]:
+            image_name: str = '', color_range: vtk.vtkLookupTable = None,
+            rgba: bool = False, show: bool = False, vtk_camera: vtk.vtkCamera = None,
+            extract_camera: bool = False) -> List[str]:
         """Export all the cameras in the scene as images.
 
         Reference: https://kitware.github.io/vtk-examples/site/Python/IO/ImageWriter/
         This method is able to export an image in '.png', '.jpg', '.ps', '.tiff', '.bmp',
         and '.pnm' formats.
 
+        Parameters vtk_camera and extract_camera are mutually exclusive and these 
+        parameters are only used by the to_grid_images method in the Model object.
+
         Args:
             folder: A valid path to where you'd like to write the images.
             image_type: An ImageType object.
@@ -225,6 +234,7 @@ class Scene:
                 Defaults to 0, which will use default radinace view's horizontal angle.
             image_height: An integer value that sets the height of image in pixels.
                 Defaults to 0, which will use default radinace view's vertical angle.
+            image_name: A text string that sets the name of the image. Defaults to ''.
             color_range: A vtk lookup table object which can be obtained
                 from the color_range mehtod of the DataFieldInfo object.
                 Defaults to None.
@@ -233,15 +243,25 @@ class Scene:
                 background color. Defaults to False.
             show: A boolean value to decide if the the render window should pop up.
                 Defaults to False.
+            vtk_camera: A vtkCamera object. If specified, this vtkCamera will be used
+                to export images. Defaults to None.
+            extract_camera: A boolean value to if active camera from the renderer in the
+                assistant shall be extracted or not. Defaults to False.
 
         Returns:
             A list of text strings representing the paths to the exported images.
         """
         self.update_scene()
 
+        if vtk_camera:
+            self._assistants[0].vtk_camera = vtk_camera
+
+        if extract_camera:
+            return self._assistants[0]._create_window()[2].GetActiveCamera()
+
         return [assistant._export_image(
             folder=folder, image_type=image_type, image_scale=image_scale,
-            image_width=image_width, image_height=image_height,
+            image_width=image_width, image_height=image_height, image_name=image_name,
             color_range=color_range, rgba=rgba, show=show)
             for assistant in self._assistants]
 
